## QtGql
###  GraphQL client for Qt-QML.
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/qtgql?style=for-the-badge)](https://pypi.org/project/qtgql/)
[![PyPI](https://img.shields.io/pypi/v/qtgql?style=for-the-badge)](https://pypi.org/project/qtgql/)
[![GitHub Workflow Status (with branch)](https://img.shields.io/github/actions/workflow/status/nrbnlulu/qtgql/tests.yml?branch=main&style=for-the-badge)
](https://github.com/nrbnlulu/qtgql/actions/workflows/tests.yml)
[![Codecov branch](https://img.shields.io/codecov/c/github/qtgql/qtgql/main?style=for-the-badge&link=https%3A%2F%2Fapp.codecov.io%2Fgh%2Fqtgql%2Fqtgql)](https://app.codecov.io/gh/qtgql/qtgql)
[![Discord](https://img.shields.io/discord/1067870318301032558?label=discord&style=for-the-badge)](https://discord.gg/5vmRRJp9fu)
![PyPI - Downloads](https://img.shields.io/pypi/dm/qtgql?style=for-the-badge)

>This project is currently under development, and **it is not** production ready,
You can play-around and tell us what is wrong / missing / awesome :smile:.
[Visit the docs for more info](https://nrbnlulu.github.io/qtgql/) (WIP).
